@@ -18,8 +18,8 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
-#ifndef KLIPPER_CLIPBOARDJOB_H
-#define KLIPPER_CLIPBOARDJOB_H
+#ifndef KATESESSIONSJOB_H
+#define KATESESSIONSJOB_H
 
 #include <Plasma/ServiceJob>
 
@@ -29,8 +29,8 @@ class KateSessionsJob : public Plasma::ServiceJob
 {
     Q_OBJECT
 public:
-    KateSessionsJob(KateSessionsEngine* engine,const QString &destination, const QString &operation, const QVariantMap &parameters, QObject *parent=0);
-    ~KateSessionsJob() = default;
+    KateSessionsJob(KateSessionsEngine* engine,const QString &destination, const QString &operation, const QVariantMap &parameters, QObject *parent=nullptr);
+    ~KateSessionsJob() override = default;
 
     void start() override;
 
