@@ -264,18 +264,12 @@ void KateViewManager::slotDocumentOpen()
 
 void KateViewManager::slotDocumentClose(KTextEditor::Document *document)
 {
-// prevent close document if only one view alive and the document of
-    // it is not modified and empty !!!
-    if ((KateApp::self()->documentManager()->documentList().size() == 1)
-            && !document->isModified()
-            && document->url().isEmpty()
-            && document->documentEnd() == KTextEditor::Cursor::start()) {
-        document->closeUrl();
-        return;
-    }
+    bool shutdownKate = m_mainWindow->modCloseAfterLast() && KateApp::self()->documentManager()->documentList().size() == 1;
 
     // close document
-    KateApp::self()->documentManager()->closeDocument(document);
+    if (KateApp::self()->documentManager()->closeDocument(document) && shutdownKate) {
+        KateApp::self()->shutdownKate(m_mainWindow);
+    }
 }
 
 void KateViewManager::slotDocumentClose()
@@ -321,7 +315,7 @@ KTextEditor::Document *KateViewManager::openUrls(const QList<QUrl> &urls,
         }
     }
 
-    return docs.isEmpty() ? 0 : docs.last();
+    return docs.isEmpty() ? nullptr : docs.last();
 }
 
 KTextEditor::View *KateViewManager::openUrlWithView(const QUrl &url, const QString &encoding)
